expected_deviation

Function expected_deviation 

fn expected_deviation(octave_span: i32) -> f64
Calculate the expected deviation for a given octave span.

This is used to normalize the output of the combined noise. Formula: 0.1 * (1 + 1/(span + 1))